@@ -5,6 +5,8 @@
 */
 
 #include "importimapsettingnofoundpage.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include <KLocalizedString>
 #include <QLabel>
 #include <QVBoxLayout>
@@ -13,7 +15,7 @@ ImportImapSettingNoFoundPage::ImportImapSettingNoFoundPage(QWidget *parent)
     : QWidget(parent)
 {
     auto mainLayout = new QVBoxLayout(this);
-    mainLayout->setObjectName(QLatin1StringView("mainlayout"));
+    mainLayout->setObjectName("mainlayout"_L1);
 
     auto lab = new QLabel(i18n("No settings found to import."));
     QFont font = lab->font();
@@ -21,7 +23,7 @@ ImportImapSettingNoFoundPage::ImportImapSettingNoFoundPage(QWidget *parent)
     font.setPointSizeF(font.pointSizeF() * 1.5);
     lab->setFont(font);
     lab->setAlignment(Qt::AlignCenter);
-    lab->setObjectName(QLatin1StringView("label"));
+    lab->setObjectName("label"_L1);
     mainLayout->addWidget(lab);
 }
 
